package com.myexample;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.UnsupportedEncodingException;
import java.util.HashMap;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.faces.model.DataModel;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlTransient;

/**
 *
 */
@XmlRootElement
@XmlSeeAlso(HashMap.class)
public class HashMapWrapper {

    private static final String NAME_KEY = "NameKey";

    private HashMap<String, Object> map = new HashMap<String, Object>();

    public HashMapWrapper() {
        
    }
    public HashMapWrapper(String name) {
        this.setValue(NAME_KEY, name);
    }

    public HashMap<String, Object> getMap() {
        return this.map;
    }
    public void setMap(HashMap<String, Object> m) {
        this.map = m;
    }

    public void setName(String name) {
        this.map.put(NAME_KEY, name);
    }
    @XmlTransient
    public String getName() {
        return (String) this.map.get(NAME_KEY);
    }

    public final void setValue(String key, Object val) {
        this.map.put(key, val);
    }
    public Object getValue(String key) {
        if (!this.map.containsKey(key)) {
            return null;
        }
        return this.map.get(key);
    }

    private static JAXBContext jc;

    private static JAXBContext getContext() {
        if (jc == null) {
            try {
                jc = JAXBContext.newInstance(HashMapWrapper.class);
            } catch (JAXBException ex) {
                Logger.getLogger(HashMapWrapper.class.getName()).log(Level.SEVERE, null, ex);
            }
        }
        return jc;
    }

    protected String marshal() {
        try {
            ByteArrayOutputStream out = new ByteArrayOutputStream();
            Marshaller marshaller = getContext().createMarshaller();
            marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, true);
            marshaller.marshal(this, out);
            return out.toString();
        } catch (JAXBException ex) {
            Logger.getLogger(DataModel.class.getName()).log(Level.SEVERE, null, ex);
        }
        return null;
    }

    protected static HashMapWrapper unmarshal(String xml) {
        Object obj = null;
        try {
            obj = getContext().createUnmarshaller().unmarshal(new ByteArrayInputStream(xml.getBytes("UTF-8")));
        } catch (UnsupportedEncodingException ex) {
            Logger.getLogger(HashMapWrapper.class.getName()).log(Level.SEVERE, null, ex);
        } catch (JAXBException ex) {
            Logger.getLogger(HashMapWrapper.class.getName()).log(Level.SEVERE, null, ex);
        }
        if (!(obj instanceof HashMapWrapper)) {
            Logger.getLogger(HashMapWrapper.class.getName()).log(Level.SEVERE,
                    "Unmarshalled object is instanceof {0} instead of HashMapWrapper", obj);
            return null;
        }
        return (HashMapWrapper)obj;
    }
}
